@@ -137,7 +137,7 @@ class HildonGui(SimpleGui):
             c.name = 'manual'
             return c
         else:
-            return startd
+            return None
 
     def set_tile_loader(self, widget, loader):
         if widget.get_active():
@@ -682,6 +682,8 @@ class HildonGui(SimpleGui):
             except Exception, e:
                 m = c
             m_new = self.show_coordinate_input(m)
+            if m_new == None:
+                return
             bar_entry.set_text(m_new.get_latlon(self.format))
 
         bar_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
@@ -696,10 +698,7 @@ class HildonGui(SimpleGui):
         dialog.vbox.pack_start(bar, False)
 
         def sel_coord(widget, data, clist):
-            tm = widget.get_model(0)
-            iter = tm.get_iter(0)
-            widget.get_selected(0, iter)
-            coord = clist[tm.get_path(iter)[0]]
+            coord = clist[self._get_selected_pos(widget)]
             bar_entry.set_text(coord.get_latlon(self.format))
 
         if self.current_cache != None:
@@ -881,6 +880,8 @@ class HildonGui(SimpleGui):
             else:
                 c = geo.Coordinate(0, 0)
             res = self.show_coordinate_input(c)
+            if res == None:
+                return
             text = "\n%s\n" % res.get_latlon(self.format)
             self.cache_notes.get_buffer().insert(self.cache_notes.get_buffer().get_end_iter(), text)
                 
@@ -942,10 +943,7 @@ class HildonGui(SimpleGui):
 
 
         def set_coord_as_target(widget):
-            tm = widget_coords.get_model(0)
-            iter = tm.get_iter(0)
-            widget_coords.get_selected(0, iter)
-            c = clist[tm.get_path(iter)[0]]
+            c = clist[self._get_selected_pos(widget_coords)]
             if c == None:
                 return
             self.set_current_cache(cache)
@@ -953,10 +951,7 @@ class HildonGui(SimpleGui):
             self.hide_cache_view()
 
         def set_alternative_position(widget):
-            tm = widget_coords.get_model(0)
-            iter = tm.get_iter(0)
-            widget_coords.get_selected(0, iter)
-            c = clist[tm.get_path(iter)[0]]
+            c = clist[self._get_selected_pos(widget_coords)]
             if c == None:
                 return
             self.core.set_alternative_position(cache, c)
@@ -1001,10 +996,7 @@ class HildonGui(SimpleGui):
 
 
         def on_imagelist_clicked(widget, data):
-            tm = widget.get_model(0)
-            iter = tm.get_iter(0)
-            widget.get_selected(0, iter)
-            path, caption = imagelist[tm.get_path(iter)[0]]
+            path, caption = imagelist[self._get_selected_pos(widget)]
             self._on_show_image(path, caption)
 
         selector.connect("changed", on_imagelist_clicked)
@@ -1192,12 +1184,13 @@ class HildonGui(SimpleGui):
 
     @staticmethod
     def _get_selected(widget):
-        tm = widget.get_model(0)
-        iter = tm.get_iter(0)
-        widget.get_selected(0, iter)
-        return tm[tm.get_path(iter)[0]]
-
+        ls, iter = widget.get_selected(0)
+        return ls[ls.get_path(iter)[0]]
 
+    @staticmethod
+    def _get_selected_pos(widget):
+        ls, iter = widget.get_selected(0)
+        return ls.get_path(iter)[0]
 
         ##############################################
         #
